==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/XfaBarcodeField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class XfaBarcodeField(XfaField):
    """
    Represents a barcode field in an XFA form.
    """

    @property
    def Length(self) -> int:
        """
        Gets the length of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_Length.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_Length.restype = c_int
        ret = GetDllLibPdf().XfaBarcodeField_get_Length(self.Ptr)
        return ret

    @Length.setter
    def Length(self, value: int):
        """
        Sets the length of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_Length.argtypes = [c_void_p, c_int]
        GetDllLibPdf().XfaBarcodeField_set_Length(self.Ptr, value)

    @property
    def Value(self) -> str:
        """
        Gets the value of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_Value.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().XfaBarcodeField_get_Value(self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_Value.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().XfaBarcodeField_set_Value(self.Ptr, value)

    @property
    def StartChar(self) -> int:
        """
        Gets the starting character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_StartChar.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_StartChar.restype = c_int
        ret = GetDllLibPdf().XfaBarcodeField_get_StartChar(self.Ptr)
        return ret

    @StartChar.setter
    def StartChar(self, value: int):
        """
        Sets the starting character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_StartChar.argtypes = [c_void_p, c_int]
        GetDllLibPdf().XfaBarcodeField_set_StartChar(self.Ptr, value)

    @property
    def EndChar(self) -> int:
        """
        Gets the ending character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_EndChar.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_EndChar.restype = c_int
        ret = GetDllLibPdf().XfaBarcodeField_get_EndChar(self.Ptr)
        return ret

    @EndChar.setter
    def EndChar(self, value: int):
        """
        Sets the ending character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_EndChar.argtypes = [c_void_p, c_int]
        GetDllLibPdf().XfaBarcodeField_set_EndChar(self.Ptr, value)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/XfaBarcodeField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class XfaBarcodeField(XfaField):
    """
    Represents a barcode field in an XFA form.
    """

    @property
    def Length(self) -> int:
        """
        Gets the length of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_Length.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_Length.restype = c_int
        ret = CallCFunction(GetDllLibPdf().XfaBarcodeField_get_Length,self.Ptr)
        return ret

    @Length.setter
    def Length(self, value: int):
        """
        Sets the length of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_Length.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().XfaBarcodeField_set_Length,self.Ptr, value)

    @property
    def Value(self) -> str:
        """
        Gets the value of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_Value.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_Value.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().XfaBarcodeField_get_Value,self.Ptr))
        return ret

    @Value.setter
    def Value(self, value: str):
        """
        Sets the value of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_Value.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().XfaBarcodeField_set_Value,self.Ptr, value)

    @property
    def StartChar(self) -> int:
        """
        Gets the starting character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_StartChar.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_StartChar.restype = c_int
        ret = CallCFunction(GetDllLibPdf().XfaBarcodeField_get_StartChar,self.Ptr)
        return ret

    @StartChar.setter
    def StartChar(self, value: int):
        """
        Sets the starting character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_StartChar.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().XfaBarcodeField_set_StartChar,self.Ptr, value)

    @property
    def EndChar(self) -> int:
        """
        Gets the ending character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_get_EndChar.argtypes = [c_void_p]
        GetDllLibPdf().XfaBarcodeField_get_EndChar.restype = c_int
        ret = CallCFunction(GetDllLibPdf().XfaBarcodeField_get_EndChar,self.Ptr)
        return ret

    @EndChar.setter
    def EndChar(self, value: int):
        """
        Sets the ending character of the barcode field.
        """
        GetDllLibPdf().XfaBarcodeField_set_EndChar.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().XfaBarcodeField_set_EndChar,self.Ptr, value)
